@@ -45,7 +45,7 @@ choose.target <- function(x,lower,upper,n,tvectors=tvectors,
     
     a <- sample(allwords[allwords >= lower & allwords <= upper])[1:n]
         
-    print(a)
+    return(a)
     
   }else{warning("tvectors must be a matrix!")}
   
